@@ -1,19 +1,19 @@
 import json
 import os
 import shutil
+from time import sleep
 
 import click
 import msal
 import requests
-from time import sleep
 
 from arcl.config import (
-    get_config_path,
+    ARCHIMEDES_CONF_DIR,
     get_api_config,
+    get_config_path,
     get_legacy_config_path,
     get_legacy_token_path,
     get_token_path,
-    ARCHIMEDES_CONF_DIR,
 )
 from arcl.token_cache import get_token_cache
 
@@ -28,20 +28,26 @@ AUTH_ACTIONS = [
     AUTH_ACTIONS_SHOW,
 ]
 
+REQUEST_TIMEOUT = 30
+
 
 def get_accepted_env():
+    """Fetches allowed values of env keys."""
     for _ in range(0, 10):
         try:
             response = requests.get(
-                "https://arclconfig.azureedge.net/config.json"
+                "https://arclconfig.azureedge.net/config.json",
+                timeout=REQUEST_TIMEOUT,
             ).json()
             return tuple(response.keys())
-        except:
+        except:  # pylint:disable=bare-except
             sleep(3)
     raise Exception("Unable to get config from arclconfig.")
 
 
 class ArchimedesAuth:
+    """Class to deal with authentication."""
+
     def __init__(self, env):
         self.env = env
         self.saved_config_path = get_config_path(env)
@@ -52,11 +58,13 @@ class ArchimedesAuth:
         )
 
     def get_scopes(self):
+        """Returns scopes."""
         return [
             f"api://{self.api_config.aad_app_client_id}/.default",
         ]
 
     def get_token_expiry(self):
+        """Returns remaining time for expiry of the token."""
         accounts = self.app.get_accounts()
         if not accounts:
             return None
@@ -66,8 +74,10 @@ class ArchimedesAuth:
         return result["expires_in"]
 
     def get_access_token_silent(self):
+        """Returns access token."""
         # We now check the cache to see
-        # whether we already have some accounts that the end user already used to sign in before.
+        # whether we already have some accounts
+        # that the end user already used to sign in before.
         accounts = self.app.get_accounts()
         if not accounts:
             return None
@@ -87,6 +97,7 @@ class ArchimedesAuth:
         return result.get("access_token")
 
     def get_access_token_by_device_flow(self):
+        """Returns access token using the browser."""
         flow = self.app.initiate_device_flow(self.get_scopes())
         message = flow.get("message")
         click.echo(message)
@@ -104,12 +115,14 @@ class ArchimedesAuth:
         return result.get("access_token")
 
     def get_access_token(self):
+        """Returns access token."""
         access_token = self.get_access_token_silent()
         if not access_token:
             access_token = self.get_access_token_by_device_flow()
         return access_token
 
     def login(self, organization_id):
+        """Method for login."""
         access_token = self.get_access_token()
 
         if organization_id is None:
@@ -123,10 +136,14 @@ class ArchimedesAuth:
                 headers={
                     "Authorization": f"Bearer {access_token}",
                 },
+                timeout=REQUEST_TIMEOUT,
             )
             page.raise_for_status()
-        except (requests.exceptions.ConnectionError, requests.exceptions.Timeout) as e:
-            click.echo("Failed connecting to the server", e)
+        except (
+            requests.exceptions.ConnectionError,
+            requests.exceptions.Timeout,
+        ) as err:
+            click.echo("Failed connecting to the server", err)
         except requests.exceptions.HTTPError:
             click.echo(page.content)
             contents = page.json()
@@ -137,7 +154,8 @@ class ArchimedesAuth:
         else:
             config = page.json()
             config_json = json.dumps(config, indent=2)
-            open(self.saved_config_path, "w").write(config_json)
+            with open(self.saved_config_path, "w", encoding="utf8") as file:
+                file.write(config_json)
             click.echo(f"Login successful into env: {self.env}")
 
             # copy jsona and msal to default files for backward compatibility
@@ -146,16 +164,17 @@ class ArchimedesAuth:
 
     @staticmethod
     def show():
+        """Prints details of all logged in users."""
         all_env_details = {}
         for env in get_accepted_env():
             saved_config_path = get_config_path(env)
             if not os.path.exists(saved_config_path):
                 continue
-            with open(saved_config_path, "r") as file:
+            with open(saved_config_path, "r", encoding="utf8") as file:
                 config = json.load(file)
             all_env_details[env] = config["user"]
 
-        if not len(all_env_details):
+        if len(all_env_details) == 0:
             click.echo("No accounts logged in.")
             return
         click.echo("Details of all accounts are below.")
@@ -183,6 +202,7 @@ class ArchimedesAuth:
             )
 
     def logout(self):
+        """Logs user out"""
         # remove older tokens created on previous versions
         for file_to_remove in (
             "arcl.json",
@@ -202,6 +222,7 @@ class ArchimedesAuth:
         click.echo(f"Logout successful from  env: {self.env}")
 
     def build_msal_app(self, client_id, cache=None):
+        """Builds a public msal app"""
         return msal.PublicClientApplication(
             client_id,
             authority=self.api_config.authority,
